HighlightText class

HighlightText is a Text widget alternative, that makes it easy to highlight concrete words, defined from pattern or from pure string.

╭──────╮ Highlight │ Data │ ╭─────────────────────────────────╮ ╰──────╯ │ ╭─────────╮ ╭───────────────╮ │ │ ╭───│ │ Pattern │ & │ Words/Letters │ │ │ │ │ ╰─────────╯ ╰───────────────╯ │ │ │ ╰─────────────────────────────────╯ ╰───────╯ │ ╭── ▼ ──╮ ╭─────────────────────────────────╮ │ Parser ───▶ ... │ Highlighted Data as Text Widget │ ╰───────╯ ╰─────────────────────────────────╯

Inheritance

Constructors

HighlightText(String data, {Key? key, required Highlight highlight, TextStyle? style, TextStyle highlightStyle = const TextStyle(color: Colors.blue, fontWeight: FontWeight.w600), bool caseSensitive = false, bool detectWords = false})

Properties

caseSensitive → bool
Enables case sensitive of parsing algorithm.
final
data → String
The default string data. Like Text widget's first required value.
final
detectWords → bool
Enables only-word detection. It wouldn't highlight matcher, if it's just a char. ╰─> {length == 1}.
final
hashCode → int
The hash code for this object.
no setterinherited
highlight → Highlight
The highlight searching model. Has two options: │─▶ Pattern - A regex pattern that would work for each char of data. ╰─▶ Words - A list of highlightable words/letters.
final
highlightStyle → TextStyle
The text style for the words/letters which would be highlighted.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → TextStyle?
The text style for the text which wouldn't be highlighted.
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited